==> jc-1.4.0.tar.gz: java/awt/event/MouseWheelEvent.h <==
// public class java.awt.event.MouseWheelEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 749c37221149979c java_awt_event_MouseEvent
// @dep_class ca71e7ac0c65cf6d java_awt_event_MouseWheelEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_MouseEvent

#include "java/awt/event/MouseEvent.h"

#ifndef _JC_java_awt_event_MouseWheelEvent_H_
#define _JC_java_awt_event_MouseWheelEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseWheelEvent$sub_refs	_jc_java_awt_event_MouseWheelEvent$sub_refs;
typedef struct _jc_java_awt_event_MouseWheelEvent$sub_nonrefs	_jc_java_awt_event_MouseWheelEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseWheelEvent$refs	_jc_java_awt_event_MouseWheelEvent$refs;
typedef struct _jc_java_awt_event_MouseWheelEvent$nonrefs	_jc_java_awt_event_MouseWheelEvent$nonrefs;
typedef struct _jc_java_awt_event_MouseWheelEvent$object	_jc_java_awt_event_MouseWheelEvent$object;

typedef struct _jc_java_awt_event_MouseWheelEvent$fields_struct	_jc_java_awt_event_MouseWheelEvent$fields_struct;
typedef const struct _jc_java_awt_event_MouseWheelEvent$vmethods	_jc_java_awt_event_MouseWheelEvent$vmethods;
typedef const struct _jc_java_awt_event_MouseWheelEvent$vtable	_jc_java_awt_event_MouseWheelEvent$vtable;
typedef const struct _jc_java_awt_event_MouseWheelEvent$vtype	_jc_java_awt_event_MouseWheelEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_MouseWheelEvent$fields_struct {
	jlong	serialVersionUID;
	jint	WHEEL__5fBLOCK__5fSCROLL;
	jint	WHEEL__5fUNIT__5fSCROLL;
};
extern _jc_java_awt_event_MouseWheelEvent$fields_struct _jc_java_awt_event_MouseWheelEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_MouseWheelEvent$method$_init$9385505990dedf0a(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean, jint, jint, jint);

// Virtual methods
extern jint _jc_java_awt_event_MouseWheelEvent$method$getScrollAmount$0fd8424baf171424(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
extern jint _jc_java_awt_event_MouseWheelEvent$method$getScrollType$05372e2706bfd988(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
extern jint _jc_java_awt_event_MouseWheelEvent$method$getUnitsToScroll$a83d908c8348da00(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
extern jint _jc_java_awt_event_MouseWheelEvent$method$getWheelRotation$aeb92c553074e437(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_event_MouseWheelEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getScrollAmount$0fd8424baf171424;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getScrollType$05372e2706bfd988;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getUnitsToScroll$a83d908c8348da00;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getWheelRotation$aeb92c553074e437;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_MouseWheelEvent$vmethods {
	jint	(*getScrollAmount$0fd8424baf171424)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
	jint	(*getScrollType$05372e2706bfd988)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
	jint	(*getUnitsToScroll$a83d908c8348da00)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
	jint	(*getWheelRotation$aeb92c553074e437)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *);
};

// Vtable
struct _jc_java_awt_event_MouseWheelEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_MouseEvent$vmethods	java_awt_event_MouseEvent;
	_jc_java_awt_event_MouseWheelEvent$vmethods	java_awt_event_MouseWheelEvent;
};

// Vtype
struct _jc_java_awt_event_MouseWheelEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseWheelEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseWheelEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseWheelEvent$refs {
    _jc_java_awt_event_MouseWheelEvent$sub_refs	java_awt_event_MouseWheelEvent;
    _jc_java_awt_event_MouseEvent$sub_refs	java_awt_event_MouseEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseWheelEvent$sub_nonrefs {
	jint	scrollType;
	jint	scrollAmount;
	jint	wheelRotation;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseWheelEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_MouseEvent$sub_nonrefs	java_awt_event_MouseEvent;
    _jc_java_awt_event_MouseWheelEvent$sub_nonrefs	java_awt_event_MouseWheelEvent;
};

// Object instance structure
struct _jc_java_awt_event_MouseWheelEvent$object {
	_jc_java_awt_event_MouseWheelEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseWheelEvent$vtype	*vtype;
	_jc_java_awt_event_MouseWheelEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseWheelEvent$vtype _jc_java_awt_event_MouseWheelEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseWheelEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseWheelEvent$class_object;

#endif	/* _JC_java_awt_event_MouseWheelEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/event/MouseWheelEvent.h <==
// public class java.awt.event.MouseWheelEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 749c37221149979c java_awt_event_MouseEvent
// @dep_class ca71e7ac0c65cf6d java_awt_event_MouseWheelEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_awt_event_MouseEvent

#include "java/awt/event/MouseEvent.h"

#ifndef _JC_java_awt_event_MouseWheelEvent_H_
#define _JC_java_awt_event_MouseWheelEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_event_MouseWheelEvent$sub_refs	_jc_java_awt_event_MouseWheelEvent$sub_refs;
typedef struct _jc_java_awt_event_MouseWheelEvent$sub_nonrefs	_jc_java_awt_event_MouseWheelEvent$sub_nonrefs;
typedef struct _jc_java_awt_event_MouseWheelEvent$refs	_jc_java_awt_event_MouseWheelEvent$refs;
typedef struct _jc_java_awt_event_MouseWheelEvent$nonrefs	_jc_java_awt_event_MouseWheelEvent$nonrefs;
typedef struct _jc_java_awt_event_MouseWheelEvent$object	_jc_java_awt_event_MouseWheelEvent$object;

typedef struct _jc_java_awt_event_MouseWheelEvent$fields_struct	_jc_java_awt_event_MouseWheelEvent$fields_struct;
typedef const struct _jc_java_awt_event_MouseWheelEvent$vmethods	_jc_java_awt_event_MouseWheelEvent$vmethods;
typedef const struct _jc_java_awt_event_MouseWheelEvent$vtable	_jc_java_awt_event_MouseWheelEvent$vtable;
typedef const struct _jc_java_awt_event_MouseWheelEvent$vtype	_jc_java_awt_event_MouseWheelEvent$vtype;

// Class fields structure
struct _jc_java_awt_event_MouseWheelEvent$fields_struct {
	jlong	serialVersionUID;
	jint	WHEEL__5fBLOCK__5fSCROLL;
	jint	WHEEL__5fUNIT__5fSCROLL;
};
extern _jc_java_awt_event_MouseWheelEvent$fields_struct _jc_java_awt_event_MouseWheelEvent$class_fields;

// Constructors
extern void _jc_java_awt_event_MouseWheelEvent$method$_init$9385505990dedf0a(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jint, jint, jboolean, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_event_MouseWheelEvent$method$getScrollAmount$0fd8424baf171424(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_MouseWheelEvent$method$getScrollType$05372e2706bfd988(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_MouseWheelEvent$method$getUnitsToScroll$a83d908c8348da00(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_event_MouseWheelEvent$method$getWheelRotation$aeb92c553074e437(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_event_MouseWheelEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getScrollAmount$0fd8424baf171424;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getScrollType$05372e2706bfd988;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getUnitsToScroll$a83d908c8348da00;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$getWheelRotation$aeb92c553074e437;
extern _jc_method _jc_java_awt_event_MouseWheelEvent$method_info$paramString$af933b2f56e61fc3;

// Virtual methods structure
struct _jc_java_awt_event_MouseWheelEvent$vmethods {
	jint	(*getScrollAmount$0fd8424baf171424)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getScrollType$05372e2706bfd988)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getUnitsToScroll$a83d908c8348da00)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
	jint	(*getWheelRotation$aeb92c553074e437)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_event_MouseWheelEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_MouseWheelEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_MouseEvent$vmethods	java_awt_event_MouseEvent;
	_jc_java_awt_event_MouseWheelEvent$vmethods	java_awt_event_MouseWheelEvent;
};

// Vtype
struct _jc_java_awt_event_MouseWheelEvent$vtype {
	_jc_type			type;
	_jc_java_awt_event_MouseWheelEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_MouseWheelEvent$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_MouseWheelEvent$refs {
    _jc_java_awt_event_MouseWheelEvent$sub_refs	java_awt_event_MouseWheelEvent;
    _jc_java_awt_event_MouseEvent$sub_refs	java_awt_event_MouseEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_MouseWheelEvent$sub_nonrefs {
	jint	scrollType;
	jint	scrollAmount;
	jint	wheelRotation;
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_MouseWheelEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_MouseEvent$sub_nonrefs	java_awt_event_MouseEvent;
    _jc_java_awt_event_MouseWheelEvent$sub_nonrefs	java_awt_event_MouseWheelEvent;
};

// Object instance structure
struct _jc_java_awt_event_MouseWheelEvent$object {
	_jc_java_awt_event_MouseWheelEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_MouseWheelEvent$vtype	*vtype;
	_jc_java_awt_event_MouseWheelEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_MouseWheelEvent$vtype _jc_java_awt_event_MouseWheelEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_MouseWheelEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_MouseWheelEvent$class_object;

#endif	/* _JC_java_awt_event_MouseWheelEvent_H_ */
